Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(36)

Unified Diff: cc/output/compositor_frame_sink_client.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/output/compositor_frame_sink.cc ('k') | cc/output/gl_renderer_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/output/compositor_frame_sink_client.h
diff --git a/cc/output/output_surface_client.h b/cc/output/compositor_frame_sink_client.h
similarity index 85%
copy from cc/output/output_surface_client.h
copy to cc/output/compositor_frame_sink_client.h
index cd91919e6c40cf0cbcb809fe3af1e4d5242027cb..4318e015f112f0393167e2becdc2f6ef9998f273 100644
--- a/cc/output/output_surface_client.h
+++ b/cc/output/compositor_frame_sink_client.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CC_OUTPUT_OUTPUT_SURFACE_CLIENT_H_
-#define CC_OUTPUT_OUTPUT_SURFACE_CLIENT_H_
+#ifndef CC_OUTPUT_COMPOSITOR_FRAME_SINK_CLIENT_H_
+#define CC_OUTPUT_COMPOSITOR_FRAME_SINK_CLIENT_H_
#include "base/callback.h"
#include "base/memory/ref_counted.h"
@@ -23,7 +23,7 @@ namespace cc {
class BeginFrameSource;
struct ManagedMemoryPolicy;
-class CC_EXPORT OutputSurfaceClient {
+class CC_EXPORT CompositorFrameSinkClient {
public:
// ============== DISPLAY COMPOSITOR ONLY =======================
@@ -36,7 +36,8 @@ class CC_EXPORT OutputSurfaceClient {
// ============== LAYER TREE COMPOSITOR ONLY ====================
// Pass the begin frame source for the client to observe. Client does not own
// the BeginFrameSource. OutputSurface should call this once after binding to
// the client and then call again with a null while detaching.
virtual void SetBeginFrameSource(BeginFrameSource* source) = 0;
virtual void ReclaimResources(const ReturnedResourceArray& resources) = 0;
@@ -46,7 +47,8 @@ class CC_EXPORT OutputSurfaceClient {
const gfx::Transform& transform) = 0;
// If set, |callback| will be called subsequent to each new tree activation,
// regardless of the compositor visibility or damage. |callback| must remain
// valid for the lifetime of the OutputSurfaceClient or until unregisted --
// use SetTreeActivationCallback(base::Closure()) to unregister it.
virtual void SetTreeActivationCallback(const base::Closure& callback) = 0;
// This allows the output surface to ask its client for a draw.
@@ -68,12 +70,12 @@ class CC_EXPORT OutputSurfaceClient {
// Needs thought, if LTHI has only context providers, it needs to register a
// lost callback, so we need to support multiple callbacks.
- virtual void DidLoseOutputSurface() = 0;
+ virtual void DidLoseCompositorFrameSink() = 0;
protected:
- virtual ~OutputSurfaceClient() {}
+ virtual ~CompositorFrameSinkClient() {}
};
} // namespace cc
-#endif // CC_OUTPUT_OUTPUT_SURFACE_CLIENT_H_
+#endif // CC_OUTPUT_COMPOSITOR_FRAME_SINK_CLIENT_H_
« no previous file with comments | « cc/output/compositor_frame_sink.cc ('k') | cc/output/gl_renderer_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -36,7 +36,8 @@ class CC_EXPORT OutputSurfaceClient {
// ============== LAYER TREE COMPOSITOR ONLY ====================
// Pass the begin frame source for the client to observe. Client does not own
- // the BeginFrameSource. OutputSurface should call this once after binding to
+ // the BeginFrameSource. CompositorFrameSink should call this once after
+ // binding to
// the client and then call again with a null while detaching.
virtual void SetBeginFrameSource(BeginFrameSource* source) = 0;
@@ -46,7 +47,8 @@ class CC_EXPORT OutputSurfaceClient {
// If set, |callback| will be called subsequent to each new tree activation,
// regardless of the compositor visibility or damage. |callback| must remain
- // valid for the lifetime of the OutputSurfaceClient or until unregisted --
+ // valid for the lifetime of the CompositorFrameSinkClient or until unregisted
+ // --
// use SetTreeActivationCallback(base::Closure()) to unregister it.
virtual void SetTreeActivationCallback(const base::Closure& callback) = 0;
This is Rietveld 408576698